@@ -15,10 +15,10 @@ class Reporter(object):
     """
     active_reporter = None
 
-    def __init__(self):
-        self.failed_test = False
+    def __init__(self, error=None):
         self.feedback = Feedback("Oh no, your solution is incorrect! Please, try again.")
         self.success_msg = "Great work!"
+        self.error = error
         self.errors_allowed = False
         self.failure_msg = ""
         self.fallback_ast = None
@@ -36,51 +36,49 @@ class Reporter(object):
             testobj.test()
             result = testobj.result
             if (not result):
-                self.failed_test = True
                 self.feedback = testobj.get_feedback()
                 self.feedback.message = self.failure_msg + self.feedback.message
                 if not self.feedback.line_info and self.fallback_ast:
                     self.feedback = Feedback(self.feedback.message, self.fallback_ast)
-                raise TestFail
 
-        else: 
+                raise TestFail(self.feedback, self.build_failed_payload())
+
+        else:
             result = None
             testobj()    # run function for side effects
 
         #self.failure_msg_stack.pop()
         return result
 
-    def build_payload(self, error):
-        if (error and not self.failed_test and not self.errors_allowed):
-            feedback_msg = "Your code contains an error: `%s`" % str(error[1])
+    def build_failed_payload(self):
+        if not self.feedback.line_info:
+            return {
+                "correct": False,
+                "message": Reporter.to_html(self.feedback.message)
+                }
+        else:
+            # Hack to make it work with campus app implementation
+            if self.feedback.line_info["column_start"] is None:
+                col_start = None
+            else:
+                col_start = self.feedback.line_info["column_start"] + 1
+
+            return {
+                "correct": False,
+                "message": Reporter.to_html(self.feedback.message),
+                "line_start": self.feedback.line_info["line_start"],
+                "column_start": col_start,
+                "line_end": self.feedback.line_info["line_end"],
+                "column_end": self.feedback.line_info["column_end"]
+                }
+
+    def build_final_payload(self):
+        if (self.error and not self.errors_allowed):
+            feedback_msg = "Your code contains an error: `%s`" % str(self.error[1])
             return {
                 "correct": False,
                 "message": Reporter.to_html(feedback_msg)
                 }
-
-        if self.failed_test:
-            if not self.feedback.line_info:
-                return {
-                    "correct": False,
-                    "message": Reporter.to_html(self.feedback.message)
-                    }
-            else:
-                # Hack to make it work with campus app implementation
-                if self.feedback.line_info["column_start"] is None:
-                    col_start = None
-                else:
-                    col_start = self.feedback.line_info["column_start"] + 1
-
-                return {
-                    "correct": False,
-                    "message": Reporter.to_html(self.feedback.message),
-                    "line_start": self.feedback.line_info["line_start"],
-                    "column_start": col_start,
-                    "line_end": self.feedback.line_info["line_end"],
-                    "column_end": self.feedback.line_info["column_end"]
-                    }
-                
-            
         else:
             return({
                 "correct": True,
