@@ -6,6 +6,7 @@ from functools import partial
 from pythonwhat.parsing import TargetVars, FunctionParser, ObjectAccessParser, parser_dict
 from pythonwhat.Reporter import Reporter
 from pythonwhat.Feedback import Feedback
+from pythonwhat.Test import Test
 from pythonwhat import signatures
 from pythonwhat.converters import get_manual_converters
 from collections.abc import Mapping
@@ -76,6 +77,7 @@ class State(object):
     """
     def __init__(self, 
                  student_context=None, solution_context=None,
+                 student_env=None, solution_env=None,
                  student_parts=None, solution_parts=None, 
                  highlight = None, messages=None, 
                  **kwargs):
@@ -102,6 +104,8 @@ class State(object):
 
         self.student_context  = Context(student_context)  if student_context is None else student_context
         self.solution_context = Context(solution_context) if solution_context is None else solution_context
+        self.student_env = Context(student_env) if student_env is None else student_env
+        self.solution_env = Context(solution_env) if solution_env is None else solution_env
 
         self.highlight = self.student_tree if (not highlight) and self.parent_state else highlight
 
@@ -158,8 +162,9 @@ class State(object):
 
         return "".join(out_list)
 
-    def to_child_state(self, student_subtree, solution_subtree, 
+    def to_child_state(self, student_subtree=None, solution_subtree=None,
                              student_context=None, solution_context=None,
+                             student_env=None, solution_env=None,
                              student_parts=None, solution_parts=None,
                              highlight = None,
                              append_message="", node_name=""):
@@ -181,11 +186,22 @@ class State(object):
         else:
             solution_context = self.solution_context
 
-        if student_context  is not None: 
-            student_context  = self.student_context.update_ctx(student_context)
+        if student_context is not None:
+            student_context = self.student_context.update_ctx(student_context)
         else:
             student_context = self.student_context
 
+        # get new envs
+        if solution_env is not None:
+            solution_env = self.solution_env.update_ctx(solution_env)
+        else:
+            solution_env = self.solution_env
+
+        if student_env is not None:
+            student_env = self.student_env.update_ctx(student_env)
+        else:
+            student_env = self.student_env
+
         if not isinstance(append_message, dict): 
             append_message =  {'msg': append_message, 'kwargs': {}}
 
@@ -193,6 +209,7 @@ class State(object):
 
         if not (solution_subtree and student_subtree):
             return self.update(student_context = student_context, solution_context = solution_context,
+                               student_env = student_env, solution_env = solution_env,
                                student_parts = student_parts, solution_parts = solution_parts,
                                highlight = highlight, messages = messages)
 
@@ -203,6 +220,8 @@ class State(object):
                       pre_exercise_code = self.pre_exercise_code,
                       student_context = student_context,
                       solution_context  = solution_context,
+                      student_env = student_env,
+                      solution_env = solution_env,
                       student_process = self.student_process,
                       solution_process = self.solution_process,
                       raw_student_output = self.raw_student_output,
@@ -235,20 +254,17 @@ class State(object):
         except IndentationError as e:
             e.filename = "script.py"
             # no line info for now
-            rep.feedback = Feedback("Your code could not be parsed due to an error in the indentation:<br>`%s.`" % str(e))
-            rep.failed_test = True
+            rep.do_test(Test(Feedback("Your code could not be parsed due to an error in the indentation:<br>`%s.`" % str(e))))
 
         except SyntaxError as e:
             e.filename = "script.py"
             # no line info for now
-            rep.feedback = Feedback("Your code can not be executed due to a syntax error:<br>`%s.`" % str(e))
-            rep.failed_test = True
+            rep.do_test(Test(Feedback("Your code can not be executed due to a syntax error:<br>`%s.`" % str(e))))
 
         # Can happen, can't catch this earlier because we can't differentiate between
         # TypeError in parsing or TypeError within code (at runtime).
         except:
-            rep.feedback.message = "Something went wrong while parsing your code."
-            rep.failed_test = True
+            rep.do_test(Test(Feedback("Something went wrong while parsing your code.")))
 
         return(res)
 
